@@ -1,7 +1,7 @@
 logLik.tvgarch <- function(object, ...)
 {
   if (!is.null(object$order.g)) {
-    result <- object$logLik
+    result <- sum(dnorm(x = object$y, mean = 0, sd = sqrt(object$h*object$g), log = TRUE))
     attr(result, "df") <- length(coef.tvgarch(object = object))
     attr(result, "nobs") <- nobs.tvgarch(object = object)
     return(result)
